==> release-notes-sles-15.3.20251031.tar.bz2: release-notes-sles-15.3.20251031/scripts/build.sh <==
#!/usr/bin/env bash
RED='\e[31m'
GREEN='\e[32m'
BLUE='\e[34m'
BOLD='\e[1m'
RESET='\e[0m'

log() {
  # $1 - optional: string: "+" for green color, "-" for red color
  # $2 - message
  colorcode="$BLUE"
  [[ "$1" == '+' ]] && colorcode="$GREEN" && shift
  [[ "$1" == '-' ]] && colorcode="$RED" && shift
  echo -e "$colorcode${1}$RESET"
}
log "Building documentation"
make html
make pdf
shopt -s globstar
mkdir public
log "Moving output files to 'public' directory"
mv **/html/release-notes "public/${PROJECT_BRANCH}"
mv **/*.pdf "public/${PROJECT_BRANCH}"
log "Adding draft warning to HTML files"
warnfiles=$(find public -type f -name '*.html')
warningtext='This is a draft document that was built and uploaded automatically. It may document beta software and be incomplete or even incorrect. <strong>Use this document at your own risk.<\/strong>'
warningbutton='I understand this is a draft'
cookiedays="0.5" # retention time for cookie = .5 days aka 12 hours
for warnfile in $warnfiles; do
sed -r -i \
    -e 's/<\/head><body[^>]*/& onload="$('"'"'#betawarn-button-wrap'"'"').toggle();if (document.cookie.length > 0) {if (document.cookie.indexOf('"'"'betawarn=closed'"'"') != -1){$('"'"'#betawarn'"'"').toggle()}};"><div id="betawarn" style="position:fixed;bottom:0;z-index:9025;background-color:#FDE8E8;padding:1em;margin-left:10%;margin-right:10%;display:block;border-top:.75em solid #E11;width:80%"><p style="color:#333;margin:1em 0;padding:0;">'"$warningtext"'<\/p> <div id="betawarn-button-wrap" style="display:none;margin:0;padding:0;"><a href="#" onclick="$('"'"'#betawarn'"'"').toggle();var d=new Date();d.setTime(d.getTime()+('"$cookiedays"'*24*60*60*1000));document.cookie='"'"'betawarn=closed; expires='"'"'+d.toUTCString()+'"'"'; path=\/'"'"'; return false;" style="color:#333;text-decoration:underline;float:left;margin-top:.5em;padding:1em;display:block;background-color:#FABEBE;">'"$warningbutton"'<\/a><\/div><\/div/' \
    -e 's/ id="(_fixed-header-wrap|_white-bg)"/& style="background-color: #E11;"/g'\
    "$warnfile"
done

==> release-notes-sles-15.4.20251031.tar.bz2: release-notes-sles-15.4.20251031/scripts/build.sh <==
#!/usr/bin/env bash
RED='\e[31m'
GREEN='\e[32m'
BLUE='\e[34m'
BOLD='\e[1m'
RESET='\e[0m'

log() {
  # $1 - optional: string: "+" for green color, "-" for red color
  # $2 - message
  colorcode="$BLUE"
  [[ "$1" == '+' ]] && colorcode="$GREEN" && shift
  [[ "$1" == '-' ]] && colorcode="$RED" && shift
  echo -e "$colorcode${1}$RESET"
}
log "Building documentation"
# set LIFECYCLE to beta for uploads to susedoc.github.io
make all
shopt -s globstar
mkdir public
[[ "$PROJECT_BRANCH" == "$CI_COMMIT_BRANCH" ]] || PROJECT_BRANCH=$CI_COMMIT_BRANCH && log "This is a merge request. Changing PROJECT_BRANCH to ${CI_COMMIT_BRANCH}"
log "Moving output files to 'public' directory"
mv **/single-html/release-notes "public/${PROJECT_BRANCH}"
mv **/*.pdf "public/${PROJECT_BRANCH}"
log "Adding draft warning to HTML files"
warnfiles=$(find public -type f -name '*.html')
warningtext='This is a draft document that was built and uploaded automatically. It may document beta software and be incomplete or even incorrect. <strong>Use this document at your own risk.<\/strong>'
warningbutton='I understand this is a draft'
cookiedays="0.5" # retention time for cookie = .5 days aka 12 hours
for warnfile in $warnfiles; do
sed -r -i \
    -e 's/<\/head><body[^>]*/& onload="$('"'"'#betawarn-button-wrap'"'"').toggle();if (document.cookie.length > 0) {if (document.cookie.indexOf('"'"'betawarn=closed'"'"') != -1){$('"'"'#betawarn'"'"').toggle()}};"><div id="betawarn" style="position:fixed;bottom:0;z-index:9025;background-color:#FDE8E8;padding:1em;margin-left:10%;margin-right:10%;display:block;border-top:.75em solid #E11;width:80%"><p style="color:#333;margin:1em 0;padding:0;">'"$warningtext"'<\/p> <div id="betawarn-button-wrap" style="display:none;margin:0;padding:0;"><a href="#" onclick="$('"'"'#betawarn'"'"').toggle();var d=new Date();d.setTime(d.getTime()+('"$cookiedays"'*24*60*60*1000));document.cookie='"'"'betawarn=closed; expires='"'"'+d.toUTCString()+'"'"'; path=\/'"'"'; return false;" style="color:#333;text-decoration:underline;float:left;margin-top:.5em;padding:1em;display:block;background-color:#FABEBE;">'"$warningbutton"'<\/a><\/div><\/div/' \
    -e 's/ id="(_fixed-header-wrap|_white-bg)"/& style="background-color: #E11;"/g'\
    "$warnfile"
done
